/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { CoreDataType, DCCDocument, HashType } from "../../../src";
import { expect } from "vitest";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:coreData";
const previousReport_base = `${base}/dcc:previousReport`;
const xpath = {
    issueDate: `string(${base}/dcc:issueDate)`,
    previousReport: {
      description: {
        content: `${previousReport_base}/dcc:description/dcc:content`
      },
      inValidityRange: `string(${previousReport_base}/dcc:inValidityRange)`,
      traceable: `string(${previousReport_base}/dcc:traceable)`,
      refType: `string(${previousReport_base}/@refType)`,
    }
};

describe("Features_DCC_v3.2.0: CoreDataType", () => {
  let dcc: DCCDocument, coreData: CoreDataType, previousReport: HashType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    coreData = dcc.digitalCalibrationCertificate.administrativeData.coreData;
    previousReport = coreData.previousReport;
  });

  test("should get correct issue date from XML", () => {
    expect(coreData.issueDate._text).toBe(select(xpath.issueDate, dom));
  });

  // region previousReport
  test("should get correct previous report description from XML", () => {
    const expected = <Element[]>select(xpath.previousReport.description.content, dom);
    expect(toTextArr(previousReport.description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct previous report inValidityRange from XML", () => {
    expect(previousReport.inValidityRange._text).toBe(select(xpath.previousReport.inValidityRange, dom));
  });

  test("should get correct previous report traceable from XML", () => {
    expect(previousReport.traceable._text).toBe(select(xpath.previousReport.traceable, dom));
  });
  // endregion

  /* test for setters */
});
