/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { ItemType, DCCDocument } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:items";
const xpath = {
  items: {
    item: {
      itemQuantities: {
        itemQuantity: {
          name: {
            content: `${base}/dcc:item[1]/dcc:itemQuantities/dcc:itemQuantity[1]/dcc:name/dcc:content`,
          },
          si_real: {
            si_value: `string(${base}/dcc:item[1]/dcc:itemQuantities/dcc:itemQuantity[1]/si:real/si:value)`,
            si_unit: `string(${base}/dcc:item[1]/dcc:itemQuantities/dcc:itemQuantity[1]/si:real/si:unit)`,
          },
        },
      },
      refType: `string(${base}/dcc:item[1]//@refType)`,
    },
  },
};

describe("Features_DCC_v3.2.0: ItemType", () => {
  let dcc: DCCDocument, item: ItemType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    item = dcc.digitalCalibrationCertificate.administrativeData.items.item[0];
  });

  test("should get correct item quantity name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.itemQuantities.itemQuantity.name.content, dom);
    expect(toTextArr(item.itemQuantities.itemQuantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item quantity real value from XML", () => {
    expect(item.itemQuantities.itemQuantity[0].real.value._text).toBe(select(xpath.items.item.itemQuantities.itemQuantity.si_real.si_value, dom));
  });

  test("should get correct item quantity real unit from XML", () => {
    expect(item.itemQuantities.itemQuantity[0].real.unit._text).toBe(select(xpath.items.item.itemQuantities.itemQuantity.si_real.si_unit, dom));
  });

  test("should get correct item refType from XML", () => {
    expect(item._attr.refType).toBe(select(xpath.items.item.refType, dom));
  });

  /* TODO: setters */
});
