/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, RefTypeDefinitionType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:refTypeDefinitions/dcc:refTypeDefinition[1]";
const xpath = {
  name: {
    content: `${base}/dcc:name/dcc:content`,
  },
  description: {
    name: {
      content: `${base}/dcc:description/dcc:name/dcc:content`,
    },
    content: `${base}/dcc:description/dcc:content`,
  },
  namespace: `string(${base}/dcc:namespace)`,
  link: `string(${base}/dcc:link)`,
  release: `string(${base}/dcc:release)`,
  value: `string(${base}/dcc:value)`,
  procedure: `string(${base}/dcc:procedure)`,
};

describe("Features_DCC_v3.2.0: RefTypeDefinitionType", () => {
  let dcc: DCCDocument, refTypeDefinition: RefTypeDefinitionType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    refTypeDefinition = dcc.digitalCalibrationCertificate.administrativeData.refTypeDefinitions.refTypeDefinition[0];
  });

  test("should get correct name from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.name.content, dom);
    expect(toTextArr(refTypeDefinition.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct description name from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.description.name.content, dom);
    expect(toTextArr(refTypeDefinition.description.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct description content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.description.content, dom);
    expect(toTextArr(refTypeDefinition.description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct namespace from XML", () => {
    expect(refTypeDefinition.namespace._text).toBe(select(xpath.namespace, dom));
  });

  test("should get correct link from XML", () => {
    expect(refTypeDefinition.link._text).toBe(select(xpath.link, dom));
  });

  test("should get correct release from XML", () => {
    expect(refTypeDefinition.release._text).toBe(select(xpath.release, dom));
  });

  test("should get correct value from XML", () => {
    expect(refTypeDefinition.value._text).toBe(select(xpath.value, dom));
  });

  test("should get correct procedure from XML", () => {
    expect(refTypeDefinition.procedure._text).toBe(select(xpath.procedure, dom));
  });
});
