/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Features_DCC_v3.2.0.xml" }
 */

import { DCCDocument, EquipmentClassType } from "../../../src";
import { JSDOM } from "jsdom";
import { select } from "../../util";
import { expect } from "vitest";

const items_base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:items";
const item_base = `${items_base}/dcc:item[1]`;
const measurementEquipments_base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]/dcc:measuringEquipments";
const measurementEquipment_base = `${measurementEquipments_base}/dcc:measuringEquipment[1]`;
describe("Features_DCC_v3.2.0: EquipmentClass", () => {
  let dcc: DCCDocument, dom: JSDOM, items_eq: EquipmentClassType[], item_eq: EquipmentClassType[], measurementEquipments_eq: EquipmentClassType[], measurementEquipment_eq: EquipmentClassType[];

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    items_eq = dcc.digitalCalibrationCertificate.administrativeData.items.equipmentClass;
    item_eq = dcc.digitalCalibrationCertificate.administrativeData.items.item[0].equipmentClass;
    measurementEquipments_eq = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].measuringEquipments.equipmentClass;
    measurementEquipment_eq = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].measuringEquipments.measuringEquipment[0].equipmentClass;
  });

  // every element contains two equipmentClass elements
  for (let i = 0; i < 2; i++) {
    // dcc:items
    test(`should get correct items equipmentClass[${i + 1}] reference from XML`, () => {
      expect(items_eq[i].reference._text).toBe(select(`string(${items_base}/dcc:equipmentClass[${i + 1}]/dcc:reference)`, dom));
    });

    test(`should get correct items equipmentClass[${i + 1}] classID from XML`, () => {
      expect(items_eq[i].classID._text).toBe(select(`string(${items_base}/dcc:equipmentClass[${i + 1}]/dcc:classID)`, dom));
    });

    // dcc:item
    test(`should get correct item equipmentClass[${i + 1}] reference from XML`, () => {
      expect(item_eq[i].reference._text).toBe(select(`string(${item_base}/dcc:equipmentClass[${i + 1}]/dcc:reference)`, dom));
    });

    test(`should get correct item equipmentClass[${i + 1}] classID from XML`, () => {
      expect(item_eq[i].classID._text).toBe(select(`string(${item_base}/dcc:equipmentClass[${i + 1}]/dcc:classID)`, dom));
    });

    // dcc:measuringEquipments
    test(`should get correct measuringEquipments equipmentClass[${i + 1}] reference from XML`, () => {
      expect(measurementEquipments_eq[i].reference._text).toBe(select(`string(${measurementEquipments_base}/dcc:equipmentClass[${i + 1}]/dcc:reference)`, dom));
    });

    test(`should get correct measuringEquipments equipmentClass[${i + 1}] classID from XML`, () => {
      expect(measurementEquipments_eq[i].classID._text).toBe(select(`string(${measurementEquipments_base}/dcc:equipmentClass[${i + 1}]/dcc:classID)`, dom));
    });

    // dcc:measuringEquipment
    test(`should get correct measuringEquipment equipmentClass[${i + 1}] reference from XML`, () => {
      expect(measurementEquipment_eq[i].reference._text).toBe(select(`string(${measurementEquipment_base}/dcc:equipmentClass[${i + 1}]/dcc:reference)`, dom));
    });

    test(`should get correct measuringEquipment equipmentClass[${i + 1}] classID from XML`, () => {
      expect(measurementEquipment_eq[i].classID._text).toBe(select(`string(${measurementEquipment_base}/dcc:equipmentClass[${i + 1}]/dcc:classID)`, dom));
    });
  }
});
