/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { ItemType, DCCDocument, IdentificationType, EquipmentClassType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:items";
const item_base = `${base}/dcc:item[1]`;
const identifications_base = `${item_base}/dcc:identifications`;
const manufacturer_base = `${identifications_base}/dcc:identification[1]`;
const customer_base = `${identifications_base}/dcc:identification[2]`;
const calibrationLaboratory_base = `${identifications_base}/dcc:identification[3]`;

const xpath = {
  items: {
    item: {
      name: {
        content: `${item_base}/dcc:name/dcc:content`,
      },
      manufacturer: {
        name: {
          content: `${item_base}/dcc:manufacturer/dcc:name/dcc:content`,
        },
      },
      model: `string(${item_base}/dcc:model)`,
      identifications: {
        manufacturer: {
          issuer: `string(${manufacturer_base}/dcc:issuer)`,
          value: `string(${manufacturer_base}/dcc:value)`,
          name: {
            content: `${manufacturer_base}/dcc:name/dcc:content`,
          },
        },
        customer: {
          issuer: `string(${customer_base}/dcc:issuer)`,
          value: `string(${customer_base}/dcc:value)`,
          name: {
            content: `${customer_base}/dcc:name/dcc:content`,
          },
        },
        calibrationLaboratory: {
          issuer: `string(${calibrationLaboratory_base}/dcc:issuer)`,
          value: `string(${calibrationLaboratory_base}/dcc:value)`,
          name: {
            content: `${calibrationLaboratory_base}/dcc:name/dcc:content`,
          },
        },
      },
      equipmentClass: {
        reference: `string(${item_base}/dcc:equipmentClass[1]/dcc:reference)`,
        classID: `string(${item_base}/dcc:equipmentClass[1]/dcc:classID)`,
      },
    },
  },
};

describe("GP_DCC_Temperature_Simplified: ItemType", () => {
  let dcc: DCCDocument, item: ItemType, manufacturer: IdentificationType, customer: IdentificationType, calibrationLaboratory: IdentificationType,
    equipmentClass: EquipmentClassType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    item = dcc.digitalCalibrationCertificate.administrativeData.items.item[0];
    manufacturer = item.identifications.identification[0];
    customer = item.identifications.identification[1];
    calibrationLaboratory = item.identifications.identification[2];
    equipmentClass = item.equipmentClass[0];
  });

  test("should get correct item name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.items.item.name.content, dom);
    expect(toTextArr(item.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item manufacturer name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.items.item.manufacturer.name.content, dom);
    expect(toTextArr(item.manufacturer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item model from XML", () => {
    expect(item.model._text).toBe(select(xpath.items.item.model, dom));
  });

  test("should get correct manufacturer identification issuer from XML", () => {
    expect(manufacturer.issuer._text).toBe(select(xpath.items.item.identifications.manufacturer.issuer, dom));
  });

  test("should get correct manufacturer identification value from XML", () => {
    expect(manufacturer.value._text).toBe(select(xpath.items.item.identifications.manufacturer.value, dom));
  });

  test("should get correct manufacturer identification name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.identifications.manufacturer.name.content, dom);
    expect(toTextArr(manufacturer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct customer identification issuer from XML", () => {
    expect(customer.issuer._text).toBe(select(xpath.items.item.identifications.customer.issuer, dom));
  });

  test("should get correct customer identification value from XML", () => {
    expect(customer.value._text).toBe(select(xpath.items.item.identifications.customer.value, dom));
  });

  test("should get correct customer identification name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.identifications.customer.name.content, dom);
    expect(toTextArr(customer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct calibration laboratory identification issuer from XML", () => {
    expect(calibrationLaboratory.issuer._text).toBe(select(xpath.items.item.identifications.calibrationLaboratory.issuer, dom));
  });

  test("should get correct calibration laboratory identification value from XML", () => {
    expect(calibrationLaboratory.value._text).toBe(select(xpath.items.item.identifications.calibrationLaboratory.value, dom));
  });

  test("should get correct calibration laboratory identification name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.identifications.calibrationLaboratory.name.content, dom);
    expect(toTextArr(calibrationLaboratory.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct equipmentClass reference from XML", () => {
    expect(equipmentClass.reference._text).toBe(select(xpath.items.item.equipmentClass.reference, dom));
  });

  test("should get correct equipmentClass classID from XML", () => {
    expect(equipmentClass.classID._text).toBe(select(xpath.items.item.equipmentClass.classID, dom));
  });

  /* TODO: setters */
});
