/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { RespPersonType, DCCDocument } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:respPersons";
const xpath = {
  respPersons: {
    respPerson1: {
      person: {
        name: {
          content: `${base}/dcc:respPerson[1]/dcc:person/dcc:name/dcc:content`,
        },
      },
      mainSigner: `string(${base}/dcc:respPerson[1]/dcc:mainSigner)`,
    },
    respPerson2: {
      person: {
        name: {
          content: `${base}/dcc:respPerson[2]/dcc:person/dcc:name/dcc:content`,
        },
      },
    },
  },
};

describe("GP_DCC_Temperature_Simplified: RespPersonType", () => {
  let dcc: DCCDocument, respPerson1, respPerson2: RespPersonType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    respPerson1 = dcc.digitalCalibrationCertificate.administrativeData.respPersons.respPerson[0];
    respPerson2 = dcc.digitalCalibrationCertificate.administrativeData.respPersons.respPerson[1];
  });

  test("should get correct responsible person 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.respPersons.respPerson1.person.name.content, dom);
    expect(toTextArr(respPerson1.person.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct responsible person 1 main signer flag from XML", () => {
    expect(respPerson1.mainSigner._text).toBe(select(xpath.respPersons.respPerson1.mainSigner, dom));
  });

  test("should get correct responsible person 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.respPersons.respPerson2.person.name.content, dom);
    expect(toTextArr(respPerson2.person.name.content)).toEqual(toTextContentArr(expected));
  });

  /* TODO: setters */
});
