/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, UsedMethodType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]";
const basic_uncertainty_base = `${base}/dcc:usedMethods/dcc:usedMethod[1]`;
const gp_temperatureSensor_base = `${base}/dcc:usedMethods/dcc:usedMethod[2]`;
const xpath = {
  usedMethods: {
    basic_uncertainty: {
      name: {
        content: `${basic_uncertainty_base}/dcc:name/dcc:content`,
      },
      description: {
        content: `${basic_uncertainty_base}/dcc:description/dcc:content`,
        contentDE: `${basic_uncertainty_base}/dcc:description/dcc:content[@lang='de']`,
        contentEN: `${basic_uncertainty_base}/dcc:description/dcc:content[@lang='en']`,
      },
      norm: `string(${basic_uncertainty_base}/dcc:norm[1])`,
      refType: `string(${basic_uncertainty_base}//@refType)`,
    },
    gp_temperatureSensor: {
      name: {
        content: `${gp_temperatureSensor_base}/dcc:name/dcc:content`,
      },
      norm: `string(${gp_temperatureSensor_base}/dcc:norm[1])`,
      refType: `string(${gp_temperatureSensor_base}//@refType)`,
    },
  },
};

describe("GP_DCC_Temperature_Simplified: UsedMethodListType", () => {
  let dcc: DCCDocument, basic_uncertainty: UsedMethodType, gp_temperatureSensor: UsedMethodType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    basic_uncertainty = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].usedMethods.usedMethod[0];
    gp_temperatureSensor = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].usedMethods.usedMethod[1];
  });

  // region basic_uncertainty
  test("should get correct basic_uncertainty name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.usedMethods.basic_uncertainty.name.content, dom);
    expect(toTextArr(basic_uncertainty.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct basic_uncertainty description content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.usedMethods.basic_uncertainty.description.content, dom);
    expect(toTextArr(basic_uncertainty.description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct basic_uncertainty norm from XML", () => {
    expect(basic_uncertainty.norm[0]._text).toBe(select(xpath.usedMethods.basic_uncertainty.norm, dom));
  });

  test("should get correct basic_uncertainty refType from XML", () => {
    expect(basic_uncertainty._attr.refType).toBe(select(xpath.usedMethods.basic_uncertainty.refType, dom));
  });
  // endregion

  // region gp_temperatureSensor
  test("should get correct gp_temperatureSensor name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.usedMethods.gp_temperatureSensor.name.content, dom);
    expect(toTextArr(gp_temperatureSensor.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct gp_temperatureSensor norm from XML", () => {
    expect(gp_temperatureSensor.norm[0]._text).toBe(select(xpath.usedMethods.gp_temperatureSensor.norm, dom));
  });

  test("should get correct gp_temperatureSensor refType from XML", () => {
    expect(gp_temperatureSensor._attr.refType).toBe(select(xpath.usedMethods.gp_temperatureSensor.refType, dom));
  });
  // endregion

  /* TODO: setters */
});
