/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Typical.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, InfluenceConditionListType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]/dcc:influenceConditions";
const xpath = {
  measurementResults: {
    measurementResult: {
      influenceConditions: {
        influenceCondition1: {
          name: {
            content: `${base}/dcc:influenceCondition[1]/dcc:name/dcc:content`,
          },
          data: {
            quantity: {
              name: {
                content: `${base}/dcc:influenceCondition[1]/dcc:data/dcc:quantity[1]/dcc:name/dcc:content`,
              },
              si_real: {
                si_value: `string(${base}/dcc:influenceCondition[1]/dcc:data/dcc:quantity[1]/si:real/si:value)`,
                si_unit: `string(${base}/dcc:influenceCondition[1]/dcc:data/dcc:quantity[1]/si:real/si:unit)`,
              },
            },
          },
          refType: `string(${base}/dcc:influenceCondition[1]//@refType)`,
        },
        influenceCondition2: {
          name: {
            content: `${base}/dcc:influenceCondition[2]/dcc:name/dcc:content`,
          },
          description: {
            content: `${base}/dcc:influenceCondition[2]/dcc:description/dcc:content`,
            contentDE: `${base}/dcc:influenceCondition[2]/dcc:description/dcc:content[@lang='de']`,
            contentEN: `${base}/dcc:influenceCondition[2]/dcc:description/dcc:content[@lang='en']`,
          },
          data: {
            quantity1: {
              name: {
                content: `${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[1]/dcc:name/dcc:content`,
              },
              si_real: {
                si_value: `string(${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[1]/si:real/si:value)`,
                si_unit: `string(${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[1]/si:real/si:unit)`,
              },
              refType: `string(${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[1]//@refType)`,
            },
            quantity2: {
              name: {
                content: `${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[2]/dcc:name/dcc:content`,
              },
              si_real: {
                si_value: `string(${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[2]/si:real/si:value)`,
                si_unit: `string(${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[2]/si:real/si:unit)`,
              },
              refType: `string(${base}/dcc:influenceCondition[2]/dcc:data/dcc:quantity[2]//@refType)`,
            },
          },
          refType: `string(${base}/dcc:influenceCondition[2]//@refType)`,
        },
        influenceCondition3: {
          name: {
            content: `${base}/dcc:influenceCondition[3]/dcc:name/dcc:content`,
          },
          description: {
            content: `${base}/dcc:influenceCondition[3]/dcc:description/dcc:content`,
            contentDE: `${base}/dcc:influenceCondition[3]/dcc:description/dcc:content[@lang='de']`,
            contentEN: `${base}/dcc:influenceCondition[3]/dcc:description/dcc:content[@lang='en']`,
          },
          data: {
            quantity1: {
              name: {
                content: `${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[1]/dcc:name/dcc:content`,
              },
              si_real: {
                si_value: `string(${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[1]/si:real/si:value)`,
                si_unit: `string(${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[1]/si:real/si:unit)`,
              },
              refType: `string(${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[1]//@refType)`,
            },
            quantity2: {
              name: {
                content: `${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[2]/dcc:name/dcc:content`,
              },
              si_real: {
                si_value: `string(${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[2]/si:real/si:value)`,
                si_unit: `string(${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[2]/si:real/si:unit)`,
              },
              refType: `string(${base}/dcc:influenceCondition[3]/dcc:data/dcc:quantity[2]//@refType)`,
            },
          },
          refType: `string(${base}/dcc:influenceCondition[3]//@refType)`,
        },
      },
    },
  },
};

describe("GP_DCC_Temperature_Typical: InfluenceConditionListType", () => {
  let dcc: DCCDocument, influenceConditions: InfluenceConditionListType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    influenceConditions = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].influenceConditions;
  });

  test("should get correct influence condition 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition1.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 1 quantity name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition1.data.quantity.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[0].data.quantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 1 quantity si:value from XML", () => {
    expect(influenceConditions.influenceCondition[0].data.quantity[0].real.value._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition1.data.quantity.si_real.si_value, dom),
    );
  });

  test("should get correct influence condition 1 quantity si:unit from XML", () => {
    expect(influenceConditions.influenceCondition[0].data.quantity[0].real.unit._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition1.data.quantity.si_real.si_unit, dom),
    );
  });

  test("should get correct influence condition 1 refType from XML", () => {
    expect(influenceConditions.influenceCondition[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition1.refType, dom),
    );
  });

  test("should get correct influence condition 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[1].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 2 description content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.description.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[1].description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 2 quantity 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.data.quantity1.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[1].data.quantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 2 quantity 1 si:value from XML", () => {
    expect(influenceConditions.influenceCondition[1].data.quantity[0].real.value._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.data.quantity1.si_real.si_value, dom),
    );
  });

  test("should get correct influence condition 2 quantity 1 si:unit from XML", () => {
    expect(influenceConditions.influenceCondition[1].data.quantity[0].real.unit._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.data.quantity1.si_real.si_unit, dom),
    );
  });

  test("should get correct influence condition 2 quantity 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.data.quantity2.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[1].data.quantity[1].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 2 quantity 2 si:value from XML", () => {
    expect(influenceConditions.influenceCondition[1].data.quantity[1].real.value._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.data.quantity2.si_real.si_value, dom),
    );
  });

  test("should get correct influence condition 2 quantity 2 si:unit from XML", () => {
    expect(influenceConditions.influenceCondition[1].data.quantity[1].real.unit._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.data.quantity2.si_real.si_unit, dom),
    );
  });

  test("should get correct influence condition 2 refType from XML", () => {
    expect(influenceConditions.influenceCondition[1]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition2.refType, dom),
    );
  });

  test("should get correct influence condition 3 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[2].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 3 description content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.description.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[2].description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 3 quantity 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.data.quantity1.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[2].data.quantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 3 quantity 1 si:value from XML", () => {
    expect(influenceConditions.influenceCondition[2].data.quantity[0].real.value._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.data.quantity1.si_real.si_value, dom),
    );
  });

  test("should get correct influence condition 3 quantity 1 si:unit from XML", () => {
    expect(influenceConditions.influenceCondition[2].data.quantity[0].real.unit._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.data.quantity1.si_real.si_unit, dom),
    );
  });

  test("should get correct influence condition 3 quantity 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.data.quantity2.name.content, dom);
    expect(toTextArr(influenceConditions.influenceCondition[2].data.quantity[1].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct influence condition 3 quantity 2 si:value from XML", () => {
    expect(influenceConditions.influenceCondition[2].data.quantity[1].real.value._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.data.quantity2.si_real.si_value, dom),
    );
  });

  test("should get correct influence condition 3 quantity 2 si:unit from XML", () => {
    expect(influenceConditions.influenceCondition[2].data.quantity[1].real.unit._text).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.data.quantity2.si_real.si_unit, dom),
    );
  });

  test("should get correct influence condition 3 refType from XML", () => {
    expect(influenceConditions.influenceCondition[2]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.influenceConditions.influenceCondition3.refType, dom),
    );
  });

  /* TODO: setters */
});
