/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Test_DCC_Minimal.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, ResultType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]/dcc:results";
const xpath = {
  measurementResults: {
    measurementResult: {
      results: {
        result: {
          name: {
            content: `${base}/dcc:result[1]/dcc:name/dcc:content`,
          },
          data: {
            list: {
              quantity: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/dcc:name/dcc:content`,
                },
                si_hybrid: {
                  si_realListXMLList1: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[1]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[1]/si:unitXMLList)`,
                  },
                  si_realListXMLList2: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[2]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[2]/si:unitXMLList)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]//@refType)`,
              },

              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list//@refType)`,
            },
          },
          refType: `string(${base}/dcc:result[1]//@refType)`,
        },
      },
    },
  },
};

describe("Test_DCC_Minimal: ResultType", () => {
  let dcc: DCCDocument, result: ResultType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    result = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].results.result[0];
  });

  test("should get correct result name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.name.content, dom);
    expect(toTextArr(result.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result quantity hybrid si:valueXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[0].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity.si_hybrid.si_realListXMLList1.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity hybrid si:unitXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[0].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity.si_hybrid.si_realListXMLList1.si_unitXMLList, dom),
    );
  });

  test("should get correct result quantity hybrid si:valueXMLList 2 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[1].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity.si_hybrid.si_realListXMLList2.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity hybrid si:unitXMLList 2: from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[1].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity.si_hybrid.si_realListXMLList2.si_unitXMLList, dom),
    );
  });

  test("should get correct result refType from XML", () => {
    expect(result._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.refType, dom));
  });

  test("should get correct result data list refType from XML", () => {
    expect(result.data.list[0]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.list.refType, dom));
  });

  test("should get correct result quantity 1 refType from XML", () => {
    expect(result.data.list[0].quantity[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity.refType, dom),
    );
  });

  /* TODO: setters */
});
