/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Regression_MathML_IsEmpty.xml" }
 */

import { select } from "../../util";
import { DCCDocument, FormulaType } from "../../../src";

const base = "//*[@refType=\"formula_01|m|x|b\"]/dcc:mathml/ml:math";
const xpath = {
  y: `string(${base}/ml:apply/ml:ci)`,
  m: `string(${base}/ml:apply/ml:apply/ml:apply/ml:ci[1])`,
  x: `string(${base}/ml:apply/ml:apply/ml:apply/ml:ci[2])`,
  b: `string(${base}/ml:apply/ml:apply/ml:ci)`,
};

describe("Regression.MathML.IsEmpty", () => {
  let dcc: DCCDocument, dom, formula: FormulaType;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
   formula = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].results.result[0].data.formula[0];
  });

  test("mathml should be defined", () => {
    expect(formula.mathml).toBeDefined();
  });

  test("should get correct y value from XML", () => {
    expect(formula.mathml["ml:math"]["ml:apply"]["ml:ci"]._text).toBe(select(xpath.y, dom));
  });

  test("should get correct m value from XML", () => {
    expect(formula.mathml["ml:math"]["ml:apply"]["ml:apply"]["ml:apply"]["ml:ci"][0]._text).toBe(select(xpath.m, dom));
  });

  test("should get correct x value from XML", () => {
    expect(formula.mathml["ml:math"]["ml:apply"]["ml:apply"]["ml:apply"]["ml:ci"][1]._text).toBe(select(xpath.x, dom));
  });

  test("should get correct b value from XML", () => {
    expect(formula.mathml["ml:math"]["ml:apply"]["ml:apply"]["ml:ci"]._text).toBe(select(xpath.b, dom));
  });
});
