import * as fs from "fs/promises";
import { DCCDocument } from "../../src";
import type { Environment } from "vitest";
import { JSDOM } from "jsdom";
import { builtinEnvironments } from "vitest/environments";

declare global {
  function recreateEnv(): { xml: string; dcc: DCCDocument; dom: JSDOM };
}

type Options = {
  custom: {
    xmlPath: string;
  };
};

async function readFile(path: string) {
  // check if file exists
  if ((await fs.stat(path)).isFile()) {
    return await fs.readFile(path, { encoding: "utf-8" });
  } else {
    throw new Error(`File ${path} does not exist.`);
  }
}

export default <Environment>({
  name: "custom",
  transformMode: "web",
  async setup(global, { custom }: Options) {
    const env = builtinEnvironments["node"];
    const envReturn = await env.setup(global, {});

    const xml = await readFile(custom.xmlPath);
    global.recreateEnv = (): { xml: string; dcc: DCCDocument; dom: JSDOM } => {
      return {
        xml,
        dcc: xml ? DCCDocument.fromXml(xml) : DCCDocument.createEmpty(),
        dom: new JSDOM(xml, { url: "http://localhost:3000", contentType: "application/xml" }),
      };
    };

    return {
      async teardown(global) {
        delete global.recreateEnv;
        await envReturn.teardown(global);
      },
    };
  },
});
